@@ -1,5 +1,6 @@
 from .group import Group
 from .user import User
 from .member import GroupMember
-from .device import GeoLocatedIP, UserDevice, UserDeviceLocation
+from .geolocated_ip import GeoLocatedIP
+from .device import UserDevice, UserDeviceLocation
 from .push import RegisteredDevice, PushConfig, NotificationTemplate, NotificationDelivery
