@@ -110,15 +110,79 @@ class Event(models.Model, MojoModel):
 
     def publish(self):
         from mojo.apps.incident.models import RuleSet
-        # Find the RuleSet by category
+        # Record metrics and find the RuleSet by category
         self.record_event_metrics()
         rule_set = RuleSet.check_by_category(self.category, self)
 
+        # Honor action=ignore from RuleSet metadata
+        if rule_set and isinstance(rule_set.metadata, dict) and rule_set.metadata.get("action") == "ignore":
+            return
+
+        # Threshold-based pending/open logic
+        min_count = None
+        window_minutes = None
+        pending_status = "pending"
+        if rule_set and isinstance(rule_set.metadata, dict):
+            try:
+                min_count = int(rule_set.metadata.get("min_count")) if rule_set.metadata.get("min_count") is not None else None
+            except Exception:
+                min_count = None
+            try:
+                window_minutes = int(rule_set.metadata.get("window_minutes")) if rule_set.metadata.get("window_minutes") is not None else None
+            except Exception:
+                window_minutes = None
+            pending_status = rule_set.metadata.get("pending_status", "pending")
+
+        # Fallback to ruleset bundling window when not provided
+        if window_minutes is None and rule_set and rule_set.bundle_minutes:
+            window_minutes = rule_set.bundle_minutes
+
+        # Count recent matching events to evaluate threshold
+        meets_threshold = True
+        event_count = 1
+        if rule_set and (min_count or window_minutes) and rule_set.bundle_by > 0:
+            criteria = {"category": self.category}
+            if window_minutes:
+                criteria["created__gte"] = dates.subtract(minutes=window_minutes)
+            b = rule_set.bundle_by
+            if b in [1, 5, 6, 9]:
+                criteria["hostname"] = self.hostname
+            if b in [2, 3, 5, 6, 7, 8]:
+                criteria["model_name"] = self.model_name
+                if b in [3, 6, 8]:
+                    criteria["model_id"] = self.model_id
+            if b in [4, 7, 8, 9]:
+                criteria["source_ip"] = self.source_ip
+
+            try:
+                event_count = self.__class__.objects.filter(**criteria).count()
+            except Exception:
+                event_count = 1
+
+            if min_count:
+                meets_threshold = event_count >= min_count
+
         if rule_set or self.level >= INCIDENT_LEVEL_THRESHOLD:
             incident, created = self.get_or_create_incident(rule_set)
+
+            # Determine status transitions for pending/open
+            prev_status = getattr(incident, "status", None)
+            if rule_set and (min_count or window_minutes):
+                try:
+                    desired_status = "open" if meets_threshold else pending_status
+                    if incident.status != desired_status:
+                        incident.status = desired_status
+                        incident.save(update_fields=["status"])
+                except Exception:
+                    pass
+
             self.link_to_incident(incident)
-            if rule_set and created:
-                rule_set.run_handler(self, incident)
+
+            # Run handlers on creation or when transitioning from pending -> open
+            if rule_set:
+                transitioned_to_open = (prev_status == pending_status and getattr(incident, "status", None) == "open")
+                if (created and (min_count is None or meets_threshold)) or transitioned_to_open:
+                    rule_set.run_handler(self, incident)
 
     def record_event_metrics(self):
         if settings.INCIDENT_EVENT_METRICS:
@@ -151,6 +215,13 @@ class Event(models.Model, MojoModel):
         if rule_set is not None and rule_set.bundle_by > 0:
             bundle_criteria = self.determine_bundle_criteria(rule_set)
             incident = Incident.objects.filter(**bundle_criteria).first()
+            # Escalate priority when reusing an existing incident
+            if incident and self.level > incident.priority:
+                incident.priority = self.level
+                try:
+                    incident.save(update_fields=['priority'])
+                except Exception:
+                    incident.save()
 
         if not incident:
             # Create a new incident if none found
@@ -167,6 +238,8 @@ class Event(models.Model, MojoModel):
                 model_id=self.model_id,
                 source_ip=self.source_ip
             )
+            self.sync_metadata()
+            self.save()
             incident.metadata.update(self.metadata)
             incident.save()
             self.record_incident_metrics()
