@@ -1,4 +1,5 @@
 from mojo import decorators as md
+from mojo import JsonResponse
 from mojo.apps.incident.models import Incident, IncidentHistory, Event, RuleSet, Rule
 
 
@@ -27,3 +28,8 @@ def on_event_ruleset(request, pk=None):
 @md.URL('event/ruleset/rule/<int:pk>')
 def on_event_ruleset_rule(request, pk=None):
     return Rule.on_rest_request(request, pk)
+
+@md.POST('event/ruleset/defaults')
+def on_event_ruleset_defaults(request):
+    RuleSet.ensure_default_rules()
+    return JsonResponse({"status": True})
